Title: Book Review: Charles Murray's <em>Human Diversity: The Biology of Gender, Race, and Class</em>
Date: 2020-01-01
Category: commentary
Tags: review (book), race, sex differences
Status: draft

[This is a pretty good book](https://www.twelvebooks.com/titles/charles-murray/human-diversity/9781538744000/) about things we know about some ways in which people are different from each other! In [my last book review](/2020/Jan/book-review-the-origins-of-unfairness/), I mentioned that I had been thinking about broadening the topic scope of this blog, and this book review seems like an okay place to start!

Honestly, I feel like I already knew most of this stuff?—sex differences in particular are kind of _my bag_—but many of the details were new to me, and it's nice to have it all bundled together in a paper book with lots of citations that I can chase down later when I'm skeptical or want more details about a specific thing! The main text is littered with pleonastic constructions like "The first author was Jane Thisand-Such" (when discussing the results of a multi-author paper) or "Details are given in the note<sup>[n]</sup>", which feel clunky to read, but are _so much better_ than the all-too-common alternative of authors _not_ "showing their work".

In the first part of this blog post, I'm going to summarize what I learned from (or was reminded of by) _Human Diversity_, but it would be kind of unhealthy for you to rely too much on tertiary blog-post summaries of secondary semi-grown-up-book literature summaries, so if these topics happen to strike your scientific curiosity, you should probably skip this post and [go buy the source material](https://www.amazon.com/dp/B07Y82KNS1/)—or maybe even a grown-up textbook!

The second part of this blog post is irrelevant.

-----

_Human Diversity_ is divided into three parts corresponding to the topics in the subtitle! (Plus another part if you want some wrapping-up commentary from Murray.) So the first part is about things we know about some ways in which female people and male people are different from each other!

The first (short) chapter is mostly about explaining [Cohen's _d_](https://en.wikiversity.org/wiki/Cohen%27s_d) [effect sizes](https://en.wikipedia.org/wiki/Effect_size), which I think are solving a very important problem! When people say "Men are taller than women" you know they don't mean _all_ men are taller than _all_ women (because you know that they know that that's obviously not true), but that just raises the question of what they _do_ mean. Saying they mean it "generally", "on average", or "statistically" doesn't really solve the problem, because that covers everything between-but-not-including "No difference" to "Yes, literally all women and all men". Cohen's _d_ is the summary statistic that lets us _quantify_ statistical differences in standardized form: once you can [visualize the overlapping distributions](https://rpsychologist.com/d3/cohend/), whether the reality of the data should be summarized in English words as a "large difference" or a "small difference" becomes a _much less interesting_ question.

Murray also addresses the issue of aggregating effect sizes—something [I've been meaning to get around to blogging about](/2018/Dec/untitled-metablogging-26-december-2018/#high-dimensional-social-science-and-the-conjunction-of-small-effect-sizes) more exhaustively for a while in this context of group differences (although at least, um, my favorite author on _Less Wrong_ [covered it in the purely abstract setting](https://www.lesswrong.com/posts/cu7YY7WdgJBs3DpmJ/the-univariate-fallacy)): small effect sizes in any single measurement can amount to a _big_ difference when you're considering many measurements at once. That's how people can distinguish female and male faces at 96% accuracy, even though there's no single measurement (like "eye width" or "nose height") offers that much predictive power.

[TODO: more examples of sex difference effect sizes, elaborate on "big" doesn't mean anything]

Subsequent chapers address sex differences in personality, cognition, interests, and the brain. It turns out that women are more warm, empathetic, æsthetically discerning, and cooperative than men are! They're also more into the Conventional, Artistic, and Social dimensions of the [Holland occupational-interests model](https://en.wikipedia.org/wiki/Holland_Codes).

You might think that this is all due to socialization, but then it's hard to explain why the same differences show up in different cultures—and why (counterintuitively) the differences seem _larger_ in richer, more feminist countries. You might think that the "larger differences in rich countries" result is an artifact: maybe people in less-feminist countries implicitly make within-sex comparisons when answering personality questions (_e.g._, "I'm aggressive _for a woman_") whereas people in more-feminist countries use a less sexist standard of comparison, construing ratings as compared to people-in-general. Murray points out that this explanation still posits the existence of large sex differences in rich countries (while explaining away the unexpected cross-cultural difference-in-differences). Another possibility is that wealth increases sexual dimorphism _in general_, including, _e.g._, height and blood pressure, not just in personality.

[TODO: tie into farmer/forager theory: http://www.overcomingbias.com/2010/10/divide-forager-v-farmer.html ]

Women are better at verbal ability and social cognition, whereas men are better at visuospatial skills. The sexes achieve similar levels of overall performance via somewhat different mental "toolkits." Murray devotes a section to a 2007 result of Johnson and Bouchard, who report that ["_g_ masks the dimensions on which [sex differences in mental abilities] lie"](/papers/johnson-bouchard-sex_differences_in_mental_abilities_g_masks_the_dimensions.pdf): overall levels of mental well-functioning lead to underestimates of the effect sizes of specific mental abilities, which you want to statistically correct for. This result in particular is _super gratifying_ to me personally, because [I independently had a similar idea a few months back](/2019/Sep/does-general-intelligence-deflate-standardized-effect-sizes-of-cognitive-sex-differences/)—it's _super validating_ as an amateur to find that the pros have been thinking along the same track!

The second part of the book is about some ways in which people with different ancestries are different from each other! Obviously, there are no "distinct" "races" (that would be dumb), but it turns out (as found by endeavors such as [Li _et al._ 2008](/papers/li_et_al-worldwide_human_relationships_inferred.pdf)) that when you throw clustering and [dimensionality-reduction](https://en.wikipedia.org/wiki/Dimensionality_reduction) algorithms at SNP data (<em>s</em>ingle <em>n</em>ucleotide <em>p</em>olymorphisms, places in the genome where more than one allele has non-negligible frequency), you get groupings that are a pretty good match to classical or self-identified "races".

Ask the computer to assume that an individual's ancestry came from _K_ fictive ancestral populations where _K_ := 2, and it'll infer that sub-Saharan Africans are descended entirely from one, East Asians and some native Americans are descended entirely from the other, and everyone else is an admixture. But if you set _K_ := 3, populations from Europe and the near East (which were construed as admixtures in the _K_ := 2 model) split off as a new inferred population cluster. And so on.

These ancestry groupings _are_ a "construct" in the sense that the groupings aren't "ordained by God"—the algorithm can find _K_ groupings for your choice of _K_—but _where_ it [draws those category boundaries](https://www.lesswrong.com/posts/esRZaPXSHgWzyB2NL/where-to-draw-the-boundaries) is a function of the data. The construct is doing _cognitive work_, concisely summarizing statistical regularities in the dataset (which is _too large_ for humans to hold in their heads all at once): a map that reflects a territory.

Twentieth-century theorists like Fisher and Haldane and whatshisface-the-guinea-pig-guy had already figured out a lot about how evolution works (stuff like, a mutation that confers a fitness advantage of _s_ has a probability of about 2<em>s</em> of sweeping to fixation), but a lot of hypotheses about recent human evolution weren't easy to test or even formulate until the genome was sequenced!

You might think that there wasn't enough _time_ in the 2–5k generations since we came forth out of Africa for much human evolution to take place: a new mutation needs to confer an unusually large benefit to sweep to fixation that fast. But what if you didn't actually need any new mutations? Natural selection on polygenic traits can also act on "standing variation": variation _already_ present in the population that was mostly neutral in previous environments, but is fitness-relevant to new selection pressures. The rapid response to selective breeding observed in domesticated plants and animals mostly doesn't depend on new mutations.

Another mechanism of recent human evolution is _introgression_: early humans interbred with our Neanderthal and Denisovan "cousins", giving our lineage the chance to "steal" all their good alleles! In contrast to new mutations, which usually die out even when they're beneficial (that 2<em>s</em> rule again), alleles "flowing" from another population keep getting reintroduced, giving them more chances to sweep!

Population differences are important when working with genome-wide association studies, because a model "trained on" one population won't perform as well against the "test set" of a different population. Suppose you do a big study and find a bunch of SNPs that correlate with a trait, like schizophrenia or liking opera. The frequencies of those SNPs for two populations from the same continent (like Japanese and Chinese) will hugely correlate (Pearson's _r_ ≈ 0.97), but for more genetically-distant populations from different continents, the correlation will still be big but not huge (like _r_ ≈ 0.8 or whatever).

What do these differences in SNP frequencies mean in practice?? We ... don't know yet. At least some population differences are fairly well-understood: I'd tell you about sickle-cell and lactase persistence, except [then I would have to scream](/2017/Dec/interlude-xi/). There are some cases where we see populations independently evolve different adaptations that solve the same problem: [people living on the plateaus of both Tibet and Peru have both adapted to high altitudes](https://www.pnas.org/content/104/suppl_1/8655.long), but the Tibetans did it by breathing faster and the Peruvians did it with more hemoglobin!

Sorry, "the Tibetans did it with ..." is sloppy phrasing on my part; what I actually mean is that the Tibetans who weren't genetically predisposed to breathe faster were more likely to die without leaving children behind. That's how evolution works!

The third part of the book is about genetic influences on class structure! Untangling the true causes of human variation is a really hard technical philosophy problem, but behavioral geneticists have at least gotten started with their simple _ACE_ model. It works like this: first, assume (that is, "pretend") that the genetic variation for a trait is _additive_ (if you have the appropriate SNP, you get more of the trait), rather than exhibiting _epistasis_ (where the effects of different loci interfere with each other) or Mendelian _dominance_ (where the presence of just one copy of an allele (of two) determines the phenotype, and it doesn't matter whether you heterozygously have a different allele as your second version of that gene). Then we pretend that we can partition the variance in phenotypes as the sum of the "additive" genetic variance _A_, plus the environmental variance "common" within a family, plus "everything else" (including measurement "error" and the not-shared-within-families "environment") _E_. Briefly (albeit at the risk of being _cliché_): nature, nurture, and _noise_.

Then we can estimate the sizes of the _A_, _C_, and _E_ components by studying fraternal and identical twins. (If you hear people talking about "twin studies", this is what they mean—_not_ case studies of identical twins raised apart, which _are_ really cool but don't happen very often.) Both kinds of twins have the same family environment _C_ at the same time (parents, socioeconomic status, schools, _&c._), but identical twins are twice as genetically related to each other as fraternal twins, so the extent to which the identical twins are more similar is going to pretty much be because of their genes. "Pretty much" in the sense that while there are ways in which the assumptions of the model aren't quite true (assortative mating makes fraternal twins more similar in the ways their parents were _already_ similar before mating, identical twins might get treated more similarly by "the environment" on account of their appearance), the _quantitative_ effect of these deviations are probably pretty small.

Anyway, it turns out that the effect of the shared environment _C_ is way smaller than most people intuitively expect—next to zero for personality and adult intelligence. The environment matters—just not the part of the environment shared by sibling in the same family. Just not the part of the environment we know how to control. Thus, a lot of economic and class stratification actually ends up being along genetic lines: the nepotism of family wealth can buy opportunities and second chances, but it doesn't actually live your life for you.

It's important not to overinterpret the heritability results; there are a bunch of standard caveats that go here that everyone's treatment of the topic needs to include. Heritability is about the _variance_ in phenotypes that can be predicted by _variance_ in genes. This is _not_ the same concept as "controlled by genes." To see this, notice that the trait "number of heads" has a heritability of zero because the variance is zero: all living people have exactly one head. (Uh, I'm counting Siamese twins as two people.) Heritability estimates are also necessarily bound to a particular population in a particular place and time, which can face constraints shaped solely by the environment. If you plant half of a batch of seeds in the shade and half in the sun, the variance in the heights of the resulting plants will be associated with variance in genetics _within_ each group, but the difference _between_ the groups is solely determined by the sunniness of their environments. Likewise, in a Society with a cruel caste system under which children with red hair are denied internet access, part of the heritability of intellectual achievement is going to come from alleles that code for red hair. Even though (_ex hypothesi_) redheads have the same inherent intellectual potential as everyone else, the heritability computation can't see into worlds that are not our own, which might have vastly different gene–environment correlations.

Old-timey geneticists used to think that they would find small number of "genes for" something, but it turns out that we live in an omnigenetic, pleiotropic world where lots and lots of SNPs each exert a tiny effect on potentially lots and lots of things. I feel like this probably _shouldn't_ have been surprising (genes code for proteins, variation in what proteins get made is going to affect high-level behaviors, but high-level behaviors involve _lots_ of proteins in a complicated unpredictable way), but I guess it was.

Murray's penultimate chapter summarizes the state of a debate between a "Robert Plomin school" and an "Eric Turkheimer school" on the impact and import of polygenic scores, where we tally up all the SNPs someone has that are associated with a trait of interest.

The starry-eyed view epitomized by Plomin says that polygenic scores are _super great_ and everyone _and her dog_ should be excited about them: they're causal in only one direction (the trait can't cause the score) and they let us assess risks in individuals before they happen. Clinical psychology will enter a new era of "positive genomics", where we understand how to work with the underlying dimensions along which people vary (including positively), rather than focusing on treated "diagnoses" that people allegedly "have".

The curmudgeonly view epitomized by Turkheimer says that science is about understanding the _causal structure_ of phenomena, and that polygenic scores don't fucking tell us anything. [Divorce is heritable _in the same way_ that intelligence is heritable](http://www.geneticshumanagency.org/gha/the-ubiquity-problem-for-group-differences-in-behavior/), not because there are divorce genes in any meaningful biological sense, but because of a "universal, nonspecific genetic pull on everything".

Notably, Plomin and Turkheimer aren't actually disagreeing here: it's a difference in emphasis rather than facts. Polygenic scores _don't_ explain mechanisms—but might they end up being useful, and used, anyway? Murray's vision of social science is content to make predictions and "explain variance" while remaining ignorant of ultimate causality. Meanwhile, my cursory understanding (while kicking myself for [_still_](/2018/Dec/untitled-metablogging-26-december-2018/#daphne-koller-and-the-methods) not having put in the hours to get farther into [_Daphne Koller and the Methods of Rationality_](https://mitpress.mit.edu/books/probabilistic-graphical-models)) was that you need to understand causality in order to predict what interventions will have what effects—maybe our feeble state of knowledge is _why_ we don't know how to find large-effect environmental interventions.

There are also some appendicies at the back of the book! Appendix 1 (reproduced from one of Murray's earlier books) explains some basic statistics concepts. Appendix 2 ("Sexual Dimorphism in Humans") goes over the prevalence of intersex conditions and gays, and then—so much for this post broadening the [topic scope of this blog](/tag/two-type-taxonomy/)—transgender typology! Murray presents the Blanchard–Bailey–Lawrence–Littman view as fact, which I think is basically _correct_, but a more comprehensive treatment (which I concede may be too much too hope for from a mere Appendix) would have at least _mentioned_ alternative views ([Serano](https://rationalwiki.org/wiki/Intrinsic_Inclinations_Model)? [Veale](/papers/veale-lomax-clarke-identity_defense_model.pdf)?), if only to explain _why_ they're worth dismissing. (Contrast to the eight pages in the main text explaining why "But, but, epigenetics!" is worth dismissing.) Then Appendix 3 ("Sex Differences in Brain Volumes and Variance") has tables of brain-size data, and an explanation of the greater-male-variance hypothesis. Cool!

-----

... and that's the book review that I would prefer to write. A science review of a science book, for science nerds. The kind of thing that would have no reason to draw your attention if you're not _genuinely interested_ in Mahanalobis _D_ effect sizes or adaptive introgression or Falconer's formula, for their own sake, or (better) for the sake of [compressing the length of the message needed to encode your observations](https://en.wikipedia.org/wiki/Minimum_message_length).

But that's not why you're reading this. That's not why Murray wrote the book. That's not even why _I'm_ writing this.





> Above all, nothing we learn will threaten human equality properly understood.

Murray quotes Stephen Pinker: "Equality is not the empirical claim that all groups of humans are interchangeable; it is the moral principle that individuals should not be judged or constrained by the average properties of their group."

[where I agree with the moral _sentiment_, but that platitude doesn't solve all the problems (notably, that's not how Bayesian reasoning works)]

[my thought: but you need causality to know the effects of interventions! Maybe that's _why_ we don't have any useful outside interventions!]

[polygenic scores are useful in the context of society's structure]

> Women in combat? It's not an issue of female courage. But from early childhood into adulthood, males are far more attracted than females to physical contests, including ones involving violence, and are more physically aggressive and risk-taking than women.



[...]

> I think at the root is the new upper class's conflaction of intellectual ability and the professions it enables with human worth. Few admit it, of course. BUt the evolving zeitgeist of the new upper class has led to a misbegotten hierarchy whereby being a surgeon is _better_ in some sense of human worth than being an insurance salesman, being an executive in a high-tech firm is _better_ than being a housewife, and a neighborhood of people with advanced degrees is _better_ than a neighborhood of high-school graduates. To put it so baldly makes it obvious how senseless it is. There shouldn't be any relationship between these things and human worth. And yet, among too many in the new upper class, there is.




As [Harold Lee points out](https://write.as/harold-lee/seizing-the-means-of-home-production), 




> The conflcation of intellectual ability with human worth helps to explain the new upper class's insistence that inequalities of intellectual ability must be the product of environmental disadvantage. Many people with high IQs really do feel sorry for people with low IQs. If the environment is to blame, then those unfortunates can be helped, and that makes people who want to help them feel good. If genes are to blame, it makes people who want to help them feel bad. People prefer feeling good to feeling bad, so they engage in confirmation bias when it comes to the evidence about the causes of human differences.


https://write.as/harold-lee/seizing-the-means-of-home-production


Moldbug's denying the moral worth of IQ: https://archive.is/9Ezk3



https://www.lesswrong.com/posts/Aud7CL7uhz55KL8jG/transhumanism-as-simplified-humanism

https://www.lesswrong.com/posts/faHbrHuPziFH7Ef7p/why-are-individual-iq-differences-ok

http://zackmdavis.net/blog/2016/08/ineffective-deconversion-pitch/

